Learn R Programming

taxotools (version 0.0.79)

DwC2taxo: Darwin Core to Taxolist format

Description

Converts a Darwin Core name list to taxolist format

Usage

DwC2taxo(namelist, statuslist = NA, source = NA)

Arguments

namelist

names list in Darwin Core format

statuslist

vector listing taxonomicStatus to be considered in the namelist. If Default value is NA, automatically uses list of

  • Synonym

  • Valid

  • heterotypicSynonym#'

  • homotypicSynonym

source

source of the namelist. Default NA

Value

names list is taxolist format

Details

The name lists downloaded for ITIS website in Darwin Core format has all the required fields. Just needs to be converted and quality checked in terms of missing linkages

See Also

Other list functions: match_lists(), synonymize_subspecies()

Examples

Run this code
# NOT RUN {
if(interactive()){
 taxolist <- DwC2taxo(namelist)
 }
# }

Run the code above in your browser using DataLab