Learn R Programming

taxotools (version 0.0.79)

build_gen_syn: Build genetic level synonyms

Description

Build a genus level synonym list from master list.

Usage

build_gen_syn(dat)

Arguments

dat

master list

Value

data frame with genus level synonyms with two columns viz. Valid_genus and Original_Genus

Details

This is to #' be passed on to get_accepted_names function as a parameter

See Also

Other Name functions: cast_canonical(), check_scientific(), expand_name(), get_accepted_names(), guess_taxo_rank(), list_higher_taxo(), melt_canonical(), melt_scientificname()

Examples

Run this code
# NOT RUN {
if(interactive()){
 gen_syn <- build_gen_syn(master)
 }
# }

Run the code above in your browser using DataLab