Learn R Programming

taxotools (version 0.0.79)

merge_lists: merge two lists of names

Description

Useful in generating a master list of names form multiple sources

Usage

merge_lists(master = NULL, checklist = NULL, verbose = TRUE)

Arguments

master

master list of names

checklist

list to be merged

verbose

verbose output on the console

Value

returns three components. First the names to be added, second the names that could not be matched and third the names that matched multiple names in master

Details

Matches names is checklist with names on master

See Also

Other List functions: cast_cs_field(), melt_cs_field(), syn2taxo(), wiki2taxo()

Examples

Run this code
# NOT RUN {
merge_lists(master = NA,
            checklist = NA,
            verbose = TRUE)
# }

Run the code above in your browser using DataLab