synonymize_subspecies: Convert all subspecies into synonyms of the species
Description
used in generating master lists
Usage
synonymize_subspecies(master, verbose = FALSE)
Arguments
master
List of names with a field named canonical
verbose
display process messages, Default: FALSE
Value
Same list of names with id and accid fields added (or data updated
the fields exists) with all subspecies linked to the species names as
synonyms
Details
While dealing with taxonomic names only at specific level,
to take advantage of sub-specific names already available in the lists
are sometimes treated as synonyms of the names at species rank. To
convert all the subspecies names as synonyms this function is very handy.