Converts a Darwin Core name list to taxolist format
Usage
DwC2taxo(namelist, statuslist = NA, source = NA)
Arguments
namelist
names list in Darwin Core format
statuslist
vector listing taxonomicStatus to be considered in
the namelist. If Default value is NA, automatically uses list of
Synonym
Valid
heterotypicSynonym#'
homotypicSynonym
source
source of the namelist. Default NA
Value
names list is taxolist format
Details
The name lists downloaded for ITIS website in Darwin Core format has
all the required fields. Just needs to be converted and quality checked in terms
of missing linkages