powered by
Useful in generating a master list of names form multiple sources
merge_lists(master = NULL, checklist = NULL, verbose = TRUE)
master list of names
list to be merged
verbose output on the console
returns three components. First the names to be added, second the names that could not be matched and third the names that matched multiple names in master
Matches names is checklist with names on master
Other List functions: cast_cs_field(), melt_cs_field(), syn2taxo(), wiki2taxo()
cast_cs_field()
melt_cs_field()
syn2taxo()
wiki2taxo()
# NOT RUN { merge_lists(master = NA, checklist = NA, verbose = TRUE) # }
Run the code above in your browser using DataLab